import {
  CreateSightPage,
  DevicesPage,
  EditSightPage,
  LoginPage,
  MainPage,
  SightPage,
  MapPage,
  MediaListPage,
  PreviewMediaPage,
  EditMediaPage,
} from "@pages";
import { authStore, createSightStore, editSightStore } from "@shared";
import { Layout } from "@widgets";
import { runInAction } from "mobx";
import React, { useEffect } from "react";

import {
  createBrowserRouter,
  RouterProvider,
  Navigate,
  Outlet,
  useLocation,
} from "react-router-dom";

const PublicRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated } = authStore;
  if (isAuthenticated) {
    return <Navigate to="/sight" replace />;
  }
  return <>{children}</>;
};

const ProtectedRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated } = authStore;
  const location = useLocation();
  if (!isAuthenticated) {
    return <Navigate to="/login" replace />;
  }
  if (location.pathname === "/") {
    return <Navigate to="/sight" replace />;
  }
  return <>{children}</>;
};

// Чтобы очистка сторов происходила при смене локации
const ClearStoresWrapper: React.FC<{ children: React.ReactNode }> = ({
  children,
}) => {
  const location = useLocation();

  useEffect(() => {
    editSightStore.clearSightInfo();
    createSightStore.clearCreateSight();
    runInAction(() => {
      editSightStore.hasLoadedCommon = false;
    });
  }, [location]);

  return <>{children}</>;
};

const router = createBrowserRouter([
  {
    path: "/login",
    element: (
      <PublicRoute>
        <LoginPage />
      </PublicRoute>
    ),
  },
  {
    path: "/",
    element: (
      <ProtectedRoute>
        <Layout>
          <ClearStoresWrapper>
            <Outlet />
          </ClearStoresWrapper>
        </Layout>
      </ProtectedRoute>
    ),
    children: [
      { index: true, element: <MainPage /> },
      { path: "sight", element: <SightPage /> },
      { path: "sight/create", element: <CreateSightPage /> },
      { path: "sight/:id", element: <EditSightPage /> },
      { path: "devices", element: <DevicesPage /> },
      { path: "map", element: <MapPage /> },
      { path: "media", element: <MediaListPage /> },
      { path: "media/:id", element: <PreviewMediaPage /> },
      { path: "media/:id/edit", element: <EditMediaPage /> },
      // { path: "media/create", element: <CreateMediaPage /> },
    ],
  },
]);

export const Router = () => {
  return <RouterProvider router={router} />;
};
